'use strict';

var path = require('path');
var isBuiltinModule = require('is-builtin-module');
var logger$1 = require('@niceties/logger');

function getOptionsObject(options, defaults, factory) {
    const result = Object.assign(Object.assign({}, defaults), options);
    if (factory) {
        for (const [k, v] of Object.entries(factory)) {
            result[k] = v(result, k);
        }
    }
    return result;
}

function logger (options) {
    return logger$1.createLogger(options.pluginName);
}

const factories = { logger };
function index (options = {}) {
    const { pluginName, external, logger, verbose } = getOptionsObject(options, {
        pluginName: '@rollup-extras/plugin-externals',
        verbose: false
    }, factories);
    const logLevel = verbose ? 1 /* LogLevel.info */ : 0 /* LogLevel.verbose */;
    return {
        name: pluginName,
        resolveId(id) {
            let isExternal = id.includes('node_modules') || isBuiltinModule(id) || path.relative('.', id).startsWith('..');
            if (external) {
                isExternal = external(id, isExternal);
            }
            logger(`'${id}' is ${isExternal ? '' : 'not '}external`, logLevel);
            return isExternal ? false : null;
        }
    };
}

module.exports = index;
